{% load sentry_helpers %}

<li class="{% cycle 'row1' 'row2' %} level-{{ group.level }}{% if priority %} priority-{{ priority }}{% endif %}" id="group_{{ group.pk }}" data-sentry-count="{{ group.times_seen }}">
	<span class="count count-digits-{{ group.times_seen|num_digits }}">{{ group.times_seen }}</span>
	<h3><a href="{% url sentry-group group.pk %}">{% if group.view %}{{ group.view }}{% else %}{{ group.message }}{% endif %}</a></h3>
	<span class="last_seen">{{ group.last_seen|timesince }}</span>
	<span class="status status-{{ group.status }}">{{ group.get_status_display }}</span>
	<p class="message">
		<span class="tag tag-level">{{ group.get_level_display }}</span> 
		<span class="tag tag-logger">{{ group.logger }}</span> 
		{% for tag in group|get_tags:request %}<span class="tag">{{ tag }}</span> {% endfor %}
		{{ group.error }}
	</p>
	<a href="{% url sentry-group group.pk %}" class="row_link"></a>
	{% if group.status == 0 %}
		<a href="{% url sentry-ajax %}?op=resolve&amp;gid={{ group.pk }}" onclick="sentryResolve({{ group.pk }});returnfalse;" class="button resolve_button hidden">&#10003;</a>
	{% endif %}
</li>
