/* http://www.positioniseverything.net/easyclearing.html */
.clearfix:after {
    content: ".";
    display: block;
    height: 0;
    clear: both;
    visibility: hidden;
}
.clearfix {display: inline-block;}
/* Hides from IE-mac \*/
.clearfix {display: block;}
* html .clearfix {height: 1%;}
/* end hide from IE-mac */

html * { padding:0; margin:0; }
body * * { padding:0; }
body { font:small sans-serif; background: #E5E5E5;
    font-family: "Lucida Grande", "Lucida Sans", verdana, sans-serif;
}
h1 { font-weight:normal; }
h1 a { color: inherit; text-decoration: none; }
h2 { margin-bottom:.4em; font-weight: normal; margin-top: .8em; margin-left: .1em; }
h2 span { font-size:80%; color:#666; font-weight:normal; }
h3 { margin:1em 0 .5em 0; }
h4 { margin:0 0 .5em 0; font-weight: normal; }
table { border:1px solid #ccc; border-collapse: collapse; width:100%; background:white; }
tbody td, tbody th { vertical-align:top; padding:2px 3px; }
thead th { padding:1px 6px 1px 3px; background:#fefefe; text-align:left; font-weight:normal; font-size:11px; border:1px solid #ddd; }
tbody th { width:12em; text-align:right; color:#666; padding-right:.5em; }
a { color: #333; }
a:visited { color: inherit; }
ul { margin: 1em 0 1em 2em; }
#header {
    position: relative;
	background: #e0ebff; border-bottom:1px solid #ddd;
	background: #555; /* for non-css3 browsers */
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#555555', endColorstr='#222222'); /* for IE */
	background: -webkit-gradient(linear, left top, left bottom, from(#555555), to(#222222)); /* for webkit browsers */
	background: -moz-linear-gradient(top,  #555,  #222); /* for firefox 3.6+ */
	border-bottom: 1px solid #000;
}

#header .container {
    position: relative;
    padding: 1em 2em;
    max-width: 1550px;
}
#header .sparkline {
    padding: 5px;
    position: absolute;
    right: 45px;
    top: 20px;
}

#account {
    position: absolute;
    right: 1em;
    top: 1.8em;
    color: #fff;
}

.nav {
    list-style: none;
    margin: 0;
    padding: 0;
}
.nav a { color: inherit; }
.nav li { display: inline; }
.nav li a { display: inline-block; }

.sentry-logo {
	display: inline-block;
	font-weight: normal;
	font-family: helvetica, sans-serif;
	font-size: 22px;
	color: #fff;
	-webkit-border-radius: 8px;
	-moz-border-radius: 8px;
	border-radius: 8px;
}
.sentry-logo small {
	font-size: 22px;
}
#header h1 {display: inline-block; font-size: 20px; line-height: 24px;
			color: #e5e5e5; text-shadow: 1px 1px 1px #333; vertical-align: middle;}
#header h2 {display: inline-block; font-size: 20px; line-height: 24px;
            margin-top: 0;
			font-weight: normal; color: #888; margin-bottom: 0; margin-left: 15px;
			color: #ccc; vertical-align: middle;}


#footer { clear: both; border-top:1px solid #ddd; background-color: #e5e5e5; }
#footer .container {
    color: #666;
    padding: 2em;
    max-width: 1550px;
}
#header table { border:none; background:transparent; }
#body, #sidebar { position: relative; }
#body {
    background: #fff;
    max-width: 100%;
    overflow: hidden;
    margin: 2em;
    border-radius: 10px;
    -moz-border-radius: 10px;
    -webkit-border-radius: 10px;
    -moz-box-shadow: 0 1px 4px #c5c5c5;
    -webkit-box-shadow: 0 1px 4px #c5c5c5;
    box-shadow: 01px 4px #c5c5c5;
    padding: 10px 20px;
    min-height: 800px;
}

#content {
    border-top: 1px solid #fff;
    overflow: hidden;
    background: #EEEEEE;
    min-width: 900px;
}

.container {
    max-width: 1600px;
    margin: 0 auto;
}

#sidebar {
    float: right;
    width: 300px;
    margin: 0em 2em 2em 0em;
    background: inherit;
    overflow: hidden;
    }

.sidebar-module {
    background: rgba(0,0,0, .03);
    -moz-border-radius: 10px;
    -webkit-border-radius: 10px;
    -moz-box-shadow: inset 0 1px 1px rgba(0,0,0, .25), 0 1px 0 #fff;
    -webkit-box-shadow: inset 0 1px 1px rgba(0,0,0, .25), 0 1px 0 #fff;
}

#sidebar .chart { margin-bottom: 1em; }

/* tracebacks */
table { border:1px solid #ccc; border-collapse: collapse; width:100%; background:white; }
tbody td, tbody th { vertical-align:top; padding:2px 3px; }
thead th { padding:1px 6px 1px 3px; background:#fefefe; text-align:left; font-weight:normal; font-size:11px; border:1px solid #ddd; }
tbody th { width:12em; text-align:right; color:#666; padding-right:.5em; }
table.vars { margin:5px 0 2px 40px; }
table.vars td, table.req td { font-family:monospace; }
table td.code { width:100%; }
table td.code div { overflow:hidden; }
table.source th { color:#666; }
table.source td { font-family:monospace; white-space:pre; border-bottom:1px solid #eee; }
ul.traceback { list-style-type:none; }
ul.traceback li.frame { margin-bottom:1em; overflow: hidden; }
div.context { margin: 10px 0; }
div.context ol { padding-left:30px; margin:0 10px; list-style-position: inside; }
div.context ol li { font-family:monospace; white-space:pre; color:#666; cursor:pointer; }
div.context ol.context-line li { color:black; background-color:#ccc; }
div.context ol.context-line li span { float: right; }
div.commands { margin-left: 40px; }
div.commands a { color:black; text-decoration:none; }
#template, #template-not-exist { background:#f6f6f6; margin-top: 1em; overflow: hidden;}
#template-not-exist ul { margin: 0 0 0 20px; }
#unicode-hint { background:#eee; }
#traceback { background:#eee; padding: 10px; }
#requestinfo { background:#f6f6f6; padding: 10px; padding-left:120px; margin-top: 1em; }
#summary { background: #ffc; padding: 10px; }
#summary h2 { font-weight: normal; color: #666; }
#explanation { background:#eee; }
#summary table { border:none; background:transparent; }
#requestinfo h2, #requestinfo h3 { position:relative; margin-left:-100px; }
#requestinfo h3 { margin-bottom:-1em; }
#reporter_body {
	padding: 8px;
	background: none repeat scroll 0 0 #FFFFCC
}
#reporter_body #traceback li { list-style-type: inherit; }
#reporter_body #traceback { padding: 8px; margin-top: 10px; }
#reporter_body td, #reporter_body th { border-bottom: 0; font:small sans-serif; line-height: auto; }
.error { background: #ffc; }
.specific { color:#cc3300; font-weight:bold; }
h2 span.commands { font-size:.7em;}
span.commands a:link {color:#5E5694;}
pre.exception_value { font-family: sans-serif; color: #666; font-size: 1.5em; margin: 10px 0 10px 0; }

/* message details */
.server-list, .url-list, .logger-list, .level-list { list-style: none; margin-left: 5px; }
.server-list li, .url-list li { padding-bottom: 10px; }
.url-list li a { line-height: 18px; }
.filter-list { margin-left: 0; text-transform: lowercase; }
.filter-list li a {
    display: block; padding: 10px; text-decoration: none;
    border-bottom: 1px solid rgba(0,0,0, .05);
    -moz-box-shadow: 0 1px 0 rgba(255,255,255, .3);
     -webkit-box-shadow: 0 1px 0 rgba(255,255,255, .3);
    font-weight: bold;
    color: #666;
    }

.filter-list li:last-child a {
    border-bottom: none;
}

.filter-list li a:hover  {
    background: rgba(131,136,142, .10);
    -moz-box-shadow: inset 0 1px 0 rgba(0,0,0, .1);
    -webkit-box-shadow: inset 0 1px 0 rgba(0,0,0, .1);
}
.filter-list li.active a {
    background: #3079d0;
    color: #fff;
    text-shadow: 0 -1px 0 #3079d0;
    border-top: 1px solid rgba(0,0,0, .2);
    border-bottom: 1px solid rgba(0,0,0, .2);
    -moz-box-shadow: inset 0 0 1px #22579b, 0 1px 0 #fff;
    -webkit-box-shadow: inset 0 0 1px #22579b, 0 1px 0 #fff;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#4da2e5', endColorstr='#3079d0'); /* for IE */
	background: -webkit-gradient(linear, left top, left bottom, from(#4da2e5), to(#3079d0)); /* for webkit browsers */
	background: -moz-linear-gradient(top,  #4da2e5,  #3079d0); /* for firefox 3.6+ */
    }

.filter-list li:first-child.active a {
    -moz-box-shadow: inset 0 1px 1px rgba(0,0,0, .30);
    -webkit-box-shadow: inset 0 1px 1px rgba(0,0,0, .30);
    }

.filter-list li:first-child a:hover, .filter-list li:first-child.active a {
    -moz-border-radius: 10px 10px 0 0;
    -webkit-border-radius: 10px 10px 0 0;
    border-radius: 10px 10px 0 0;
    border-top: 0;
}
.filter-list li:last-child a:hover, .filter-list li:last-child.active a {
    -moz-border-radius: 0 0 10px 10px;
    -webkit-border-radius: 0 0 10px 10px;
    border-radius: 0 0 10px 10px;
    border-bottom: 0;
    -moz-box-shadow: none;
}

.filter-list li:first-child:last-child.active a {
    -moz-box-shadow: inset 1px 1px 1px rgba(0,0,0, .30);
    -webkit-box-shadow: inset 1px 1px 1px rgba(0,0,0, .30);
    }

.filter-list li:first-child:last-child a:hover, .filter-list li:first-child:last-child.active a {
    -moz-border-radius: 10px;
    -webkit-border-radius: 10px;
    border-radius: 10px;
}
.filter-list li.active a { font-weight: bold; }
dl.flat {
	margin-bottom: 1em;
}
dl.flat dt {
	float: left;
	clear: left;
	width: 90px;
	padding-bottom: 5px;
}
dl.flat dd {
	padding-bottom: 5px;
}
/* messages generic */
.count { background: #000; -moz-border-radius: 4px; -webkit-border-radius: 4px; border-radius: 4px; padding: 0 5px; margin-right: 3px; line-height: 19px; color: #fff; display: inline-block; }
.count-digits-4 { font-size: 0.8em; }
.count-digits-5 { font-size: 0.7em; }

/* message list */
.messages { list-style: none; margin-left: 0; }
.messages li { list-style: none; }
.messages .count {
	width: 28px; text-align: center;
	-webkit-border-radius: 6px;
	-moz-border-radius: 6px;
	border-radius: 6px;
	padding: 4px; line-height: 19px; color: #fff; display: inline-block; margin-right: 5px;
}
.messages h3 {
    height: 20px;
    line-height: 20px;
    display: inline-block;
    margin: 0;
    white-space: nowrap;
    overflow: hidden;
    max-width: 80%;
}
.messages h3 a { text-decoration: none; }
.messages .message {
	color: #666;
	margin-top: 8px;
	font-size: 0.9em;
	overflow: hidden;
	white-space: nowrap;
}

.messages .tag { display: inline-block; padding: 2px 5px; background: #eaeaea; margin-right: 5px;}
.messages .traceback { display: none; }
.messages li { padding: 8px; position: relative; padding-right: 50px; overflow: hidden;}
.messages .row1 { background: #f9f9f9; }
.messages .hidden {
	position: absolute;
	right: 15px;
	top: 21px;
    visibility: hidden;;
}
.messages li:hover .hidden {
    visibility: visible;
}

.row_link {
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    position: absolute;
}

.button {
    cursor: pointer;
    display: inline-block;
	color: #888;
	padding: 5px 8px 5px 8px;
    font-size: 12px;
    line-height: 12px;
    border:1px solid #C5C5C5;
	text-decoration: none;
	-webkit-border-radius: 6px;
	-moz-border-radius: 6px;
	border-radius: 6px;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#FFF', endColorstr='#DCDCDC'); /* for IE */
	background: -webkit-gradient(linear, left top, left bottom, from(#FFF), to(#DCDCDC)); /* for webkit browsers */
    background:-moz-linear-gradient(center top , #FFFFFF 0pt, #DCDCDC 100%) repeat scroll 0 0 transparent;
}

.button:hover {
    border:1px solid #3079d0;
    color: #fff;
    text-shadow: 0 -1px 0 #3079d0;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#4da2e5', endColorstr='#3079d0'); /* for IE */
	background: -webkit-gradient(linear, left top, left bottom, from(#4da2e5), to(#3079d0)); /* for webkit browsers */
	background: -moz-linear-gradient(top,  #4da2e5,  #3079d0); /* for firefox 3.6+ */

}
.priority-veryhigh .count {
	background: #e22e2e;
	-webkit-box-shadow: 0 1px 2px rgba(0,0,0,.2);
	-moz-box-shadow: 0 1px 2px rgba(0,0,0,.2);
	box-shadow: 0 1px 2px rgba(0,0,0,.2);
	background:-moz-linear-gradient(center top , #ED1C24, #AA1317) repeat scroll 0 0 transparent;
	background:-webkit-gradient(linear, 0% 0%, 0% 100%, from(#ED1C24), to(#AA1317));
}
.priority-high .count {
	background: #ff5400;
	background:-moz-linear-gradient(center top , #F16C7C, #BF404F) repeat scroll 0 0 transparent;
	background:-webkit-gradient(linear, 0% 0%, 0% 100%, from(#F16C7C), to(#BF404F));
}
.priority-medium .count {
	background: #ff7800;
	background:-moz-linear-gradient(center top , #FAA51A, #F47A20) repeat scroll 0 0 transparent;
	background:-webkit-gradient(linear, 0% 0%, 0% 100%, from(#FAA51A), to(#F47A20));
}
.priority-low .count,
.priority-verylow .count {
	background: #ffb400;
	background:-moz-linear-gradient(center top , #efd57c, #e0ae00) repeat scroll 0 0 transparent;
	background:-webkit-gradient(linear, 0% 0%, 0% 100%, from(#efd57c), to(#e0ae00));
}
.messages .last_seen { color: #bbb; font-size: 0.9em; margin-left: 5px; white-space: nowrap; }
.messages .status { margin-left: 5px; text-transform: uppercase; font-size: 0.9em; }
.messages .status-0 { display: none; }
.messages .status-1 { color: red; }
.messages li:hover, .messages .active {
	background: #eaeaea;
	-webkit-border-radius: 6px;
	-moz-border-radius: 6px;
	border-radius: 6px;
}
.messages li:hover .tag { background: #fff; }
.messages li:hover h3 a {
    color: #006CA3;
}
.messages li:hover .last_seen, .messages .active .last_seen { color: #777; }
pre {
	display: block;
	white-space: pre-wrap;	   /* CSS-3				  */
	white-space: -moz-pre-wrap;  /* Mozilla, since 1999	*/
	white-space: -pre-wrap;	  /* Opera 4-6			  */
	white-space: -o-pre-wrap;	/* Opera 7				*/
	word-wrap: break-word;	   /* Internet Explorer 5.5+ */
}
.no-messages { font-size: 1.1em; padding: 20px 0; }

.paging-wrap {
    display: inline; float: left;
    width: 100%;
}
.paging-meta, .sort-by, .realtime {
    display: inline;
    float: right;
    margin: 10px 10px 0 0;
    font-size: 14px;
    line-height: 17px;
    color: #aaa;
    font-weight: bold;
}
.paging-meta {
    padding: 6px 8px;
}
.paging-endless {
    display: inline; float: left;
    margin: 10px 0 0 10px;
}

.paging-endless li {
    float: left; display: inline;
    margin-right: 15px;
}

.paging-endless li span {
    display: inline-block;
	padding: 6px 8px 6px 8px;
    color: #aaa;
    font-size: 12px;
    line-height: 17px;
    border:1px solid #ddd;
	text-decoration: none;
	-webkit-border-radius: 6px;
	-moz-border-radius: 6px;
    opacity: 0.75;
	border-radius: 6px;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#FFF', endColorstr='#DCDCDC'); /* for IE */
	background: -webkit-gradient(linear, left top, left bottom, from(#FFF), to(#DCDCDC)); /* for webkit browsers */
    background:-moz-linear-gradient(center top , #FFFFFF 0pt, #DCDCDC 100%) repeat scroll 0 0 transparent;
}

.paging-endless li a,
.sort-by, .realtime {
    display: inline-block;
    text-decoration: none;
	color: #888;
	padding: 6px 8px 6px 8px;
    font-size: 12px;
    line-height: 17px;
    border:1px solid #C5C5C5;
	text-decoration: none;
	-webkit-border-radius: 6px;
	-moz-border-radius: 6px;
	border-radius: 6px;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#FFF', endColorstr='#DCDCDC'); /* for IE */
	background: -webkit-gradient(linear, left top, left bottom, from(#FFF), to(#DCDCDC)); /* for webkit browsers */
    background:-moz-linear-gradient(center top , #FFFFFF 0pt, #DCDCDC 100%) repeat scroll 0 0 transparent;
}

.paging-endless li a:hover,
.realtime:hover {
    cursor: pointer;
    border:1px solid #3079d0;
    color: #fff;
    text-shadow: 0 -1px 0 #3079d0;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#4da2e5', endColorstr='#3079d0'); /* for IE */
	background: -webkit-gradient(linear, left top, left bottom, from(#4da2e5), to(#3079d0)); /* for webkit browsers */
	background: -moz-linear-gradient(top,  #4da2e5,  #3079d0); /* for firefox 3.6+ */
}

.sort-by select {
    border: 0;
    margin-left: 4px;
    background: inherit;
}

#search {
    float: right;
    background: rgba(255,255,255,.50);
    -moz-border-radius: 18px;
    -webkit-border-radius: 18px;
	border-radius: 18px;
    -moz-box-shadow: inset 0 1px 5px rgba(0,0,0, .30), 0 1px 0 #fff;
    -webkit-box-shadow: inset 0 1px 5px rgba(0,0,0, .30), 0 1px 0 #fff;
    position: relative;
}

#search .textfield input {
    border: 0;
    background: transparent;
    padding: 8px 16px;
    font-size: 16px;
    color: #666;
    width: 267px;
}

#search .submit {
    position: absolute;
    right: 16px;
    top: 12px;
    opacity: .6;
}

.search-submit {
    display: block;
    width: 12px;
    height: 12px;
    background: #fff url(../images/search.png);
    text-indent: -9999em;
    border: none;
}

.login-area {
    width: 300px;
    margin: 50px auto;
    background: #eee;
    border: 1px solid #ddd;
    padding: 10px;
}
form table {
    border: 0;
    margin: 1em 0;
    background: inherit;
}
form table td { padding: 5px; }
form .submit { text-align: right; }

form td textarea {
    min-height: 250px;
}
form td textarea,
form td input {
    width: 100%;
    padding: 3px;
    border: 1px solid #ccc;
    -moz-border-radius: 6px;
    -webkit-border-radius: 6px;
    border-radius: 6px;
}
form td textarea:focus,
form td input:focus {
    border-color: #333;
}

#group_nav {
    border-bottom: 1px solid #ddd;
}
#group_nav a {
    -moz-border-radius: 6px 6px 0 0;
    -webkit-border-radius: 6px 6px 0 0;
    border-radius: 6px 6px 0 0;
    padding: 6px 12px;
    text-decoration: none;
}
#group_nav a:hover {
    background: #eee;
}
#group_nav .active a {
    background: #ddd;
}
h2 .morelink { text-decoration: none; }