{% load sentry_helpers %}

{% with group.unique_urls|slice:"10" as unique_urls %}
	{% if unique_urls %}
		<h2>URLs</h2>

		<ul class="url-list">
			{% for link, priority in unique_urls|with_priority:"times_seen" %}
				<li class="priority-{{ priority }}"><span class="count">{{ link.times_seen }}</span> <a href="{{ link.url }}">{{ link.url }}</a></li>
			{% endfor %}
		</ul>
	{% endif %}
{% endwith %}